========
WasabiS3
========


.. image:: https://img.shields.io/pypi/v/wasabis3.svg
        :target: https://pypi.python.org/pypi/wasabis3

.. image:: https://img.shields.io/travis/salimdason/wasabis3.svg
        :target: https://travis-ci.com/salimdason/wasabis3

.. image:: https://readthedocs.org/projects/wasabis3/badge/?version=latest
        :target: https://wasabis3.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/salimdason/wasabis3/shield.svg
     :target: https://pyup.io/repos/github/salimdason/wasabis3/
     :alt: Updates



A suite of maintenance tools for Wasabi S3 buckets


* Free software: GNU General Public License v3
* Documentation: https://wasabis3.readthedocs.io.


Features
--------

1. Delete only non-current objects
2. Delete both current and non-current objects
3. Purge delete markers from bucket
4. Delete bucket (after running above commands to ensure it's empty)

